#!/usr/bin/env python
"""
Copyright 2012 Wordnik, Inc.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""
class Employee:
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        self.swaggerTypes = {
            'ssn': 'str',
            'last_name': 'str',
            'middle_name': 'str',
            'emergency_contact_number': 'str',
            'date_terminated': 'str',
            'dob': 'str',
            'alcohol_commission_number': 'str',
            'alcohol_commission_expiration_date': 'str',
            'first_name': 'str',
            'is_manager': 'bool',
            'health_cert_number': 'str',
            'mobile_phone': 'str',
            'date_hired': 'str',
            'home_phone': 'str',
            'country_of_nationality': 'str',
            'emergency_contact_name': 'str',
            'health_cert_expiration_date': 'str',
            'date_last_review': 'str',
            'user_name': 'str',
            'email': 'str',
            'employee_id': 'int'

        }


        #Social Security Number
        self.ssn = None # str
        #Last Name
        self.last_name = None # str
        #Middle Name
        self.middle_name = None # str
        #Emergency Contact Number
        self.emergency_contact_number = None # str
        #Date of Termination
        self.date_terminated = None # str
        #Date of Birth
        self.dob = None # str
        #Alcohol Commission Certification Number
        self.alcohol_commission_number = None # str
        #Alcohol Commission Certification Expiration Date
        self.alcohol_commission_expiration_date = None # str
        #First Name
        self.first_name = None # str
        #Manager Flag
        self.is_manager = None # bool
        #Board of Health Certification Number
        self.health_cert_number = None # str
        #Mobile Phone Number
        self.mobile_phone = None # str
        #Hire Date
        self.date_hired = None # str
        #Home Phone Number
        self.home_phone = None # str
        #Country of Nationality
        self.country_of_nationality = None # str
        #Emergency Contact Name
        self.emergency_contact_name = None # str
        #Board of Health Certification Expiration Date
        self.health_cert_expiration_date = None # str
        #Last Review Date
        self.date_last_review = None # str
        #Employee User Name
        self.user_name = None # str
        #Email Address
        self.email = None # str
        #Employee ID
        self.employee_id = None # int
        



#!/usr/bin/env python
"""
Copyright 2012 Wordnik, Inc.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""
class CardPayment:
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        self.swaggerTypes = {
            'name_on_card': 'str',
            'tip_amount': 'float',
            'expiration_year': 'str',
            'amount_before_tip': 'float',
            'tip_type': 'int',
            'card_id': 'int',
            'expiration_month': 'str',
            'mag_track_2': 'str',
            'mag_track_1': 'str',
            'signature_image': 'str',
            'tender_type_id': 'int',
            'billing_zip': 'str',
            'card_number': 'str'

        }


        #Name on card
        self.name_on_card = None # str
        #Payment Tip Amount
        self.tip_amount = None # float
        #Expration Year
        self.expiration_year = None # str
        #Payment Amount Before Tip
        self.amount_before_tip = None # float
        #Pass tip ID or use 0 to specify tip
        self.tip_type = None # int
        #SubtleData Credit or Gift Card ID
        self.card_id = None # int
        #Expration Month
        self.expiration_month = None # str
        #Mag Track 2 Data
        self.mag_track_2 = None # str
        #Mag Track 1 Data
        self.mag_track_1 = None # str
        #Signature Image in Base64
        self.signature_image = None # str
        #tender_type_id
        self.tender_type_id = None # int
        #Billing Zip Code
        self.billing_zip = None # str
        #CC Number
        self.card_number = None # str
        



__author__ = 'gsibble'

from base_types import SDFirstClassObject
from sd_ticket import SDTicket
from sd_collections_tickets import SDTicketCollection

class SDTable(SDFirstClassObject):

    def __init__(self, parent, location, swagger_table, use_cache=True):
        """

        :param parent:
        :param location:
        :param swagger_table:
        :param use_cache:
        """
        super(SDTable, self).__init__(location, use_cache)
        self.parent = parent
        self.location = location
        self.refresh(swagger_table=swagger_table)

    def refresh(self, swagger_table=None):

        """

        :param swagger_table:
        :raise:
        """
        if swagger_table == None:
            if hasattr(self, 'subtledata_id'):
                self._swagger_table = self._swagger_locations_api.getTable(location_id=self.location.location_id,
                                                                           table_id=self.subtledata_id,
                                                                           api_key=self._api_key)
            else:
                raise ValueError('Table has no ID')
        else:
            self._swagger_table = swagger_table

        for attribute in self._swagger_table.swaggerTypes:
            if attribute != 'open_tickets':
                self.__setattr__(attribute, getattr(self._swagger_table, attribute))
            else:
                self.__setattr__('_swagger_tickets', getattr(self._swagger_table, 'open_tickets'))

    def open_ticket(self, user_id, device_id, number_of_people_in_party=1, business_expense=False, custom_ticket_name=None, return_ticket_details=False):
        """

        :param user_id:
        :param device_id:
        :param number_of_people_in_party:
        :param business_expense:
        :param custom_ticket_name:
        :param return_ticket_details:
        :return: :raise:
        """
        if hasattr(self, 'revenue_center_id') and hasattr(self, 'subtledata_id'):
            ticket_body = {
                "revenue_center_id": self.revenue_center_id,
                "number_of_people_in_party": number_of_people_in_party,
                "user_id": user_id,
                "device_id": device_id,
                "table_id": self.subtledata_id,
                "business_expense": business_expense,
                "custom_ticket_name": custom_ticket_name
            }
        else:
            raise KeyError('Table missing key data')

        #Send the request
        ticket_response = self._swagger_locations_api.createTicket(self.location._location_id, self._api_key, ticket_type='dine-in', body=ticket_body)

        if return_ticket_details:
            #Get the totals
            return SDTicket(parent=self, location=self.location, ticket_id=ticket_response.ticket_id, user_id=user_id, get_values=True)

        else:
            return SDTicket(parent=self, location=self.location, ticket_id=ticket_response.ticket_id, user_id=user_id, get_values=False)

    @property
    def open_tickets(self):
        self.refresh()
        ticket_list = [SDTicket(parent=self, location=self.location, ticket_id=ticket.ticket_id, user_id=ticket.user_id, swagger_ticket=ticket, get_values=False) for ticket in self._swagger_tickets]

        return ticket_list



__author__ = 'gsibble'

from base_types import SDFirstClassObject
from sd_menu import SDMenu
from sd_table import SDTable
from sd_ticket import SDTicket
from sd_collections_tables import SDTableCollection
from sd_collections_tickets import SDTicketCollection


class SDLocation(SDFirstClassObject):
    def __init__(self, parent, location_id, include_menu=False, use_cache=True, fetch=True, initial_data=None, *args,
                 **kwargs):
        """

        :param parent:
        :param location_id:
        :param include_menu:
        :param use_cache:
        :param fetch:
        :param initial_data:
        :param args:
        :param kwargs:
        """
        super(SDLocation, self).__init__(parent, use_cache)
        self._location_id = location_id
        self._include_menu = include_menu

        if fetch:
            self.refresh()
        else:
            if initial_data:
                self._set_attribs(initial_data)


    def refresh(self):
        #Get the location via swagger
        """


        """
        self._swagger_location = self._swagger_locations_api.getLocation(self._location_id, self._api_key,
                                                                         use_cache=self._use_cache)

        #Set attributes of first class Location to match Swagger Location object
        self._set_attribs(self._swagger_location)

        if self._include_menu:
            self.update_menu(self._use_cache)

    @property
    def tables(self):
        """


        :return:
        """
        return SDTableCollection(parent=self)

    def update_menu(self, use_cache=True):
        """

        :param use_cache:
        """
        if not self._use_cache:
            use_cache = False

        self._swagger_menu = self._swagger_locations_api.getLocationMenu(self._location_id, self._api_key,
                                                                         use_cache=use_cache)

    @property
    def menu(self):
        """


        :return:
        """
        if not hasattr(self, '_swagger_menu'):
            self.update_menu()

        return SDMenu(self, self._swagger_menu)

    @property
    def open_tables(self):
        """


        :return:
        """
        return []

    def open_ticket_for_take_out(self, user_id, device_id, revenue_center_id, number_of_people_in_party=1, business_expense=False, custom_ticket_name=None, table_id=None):
        """
        Open a ticket for take out

        :param user_id: SubtleData User ID for order
        :param device_id: User's associated device ID
        :param revenue_center_id: Revenue Center for Take Out orders
        :param number_of_people_in_party: Number of people in the party
        :param business_expense: Whether this is a business expense
        :param custom_ticket_name: Custom ticket name to display
        :param table_id: Table ID to use
        :return: SDTicket Object and Status
        :raise: RunTimeError with error details
        """
        ticket_body = {
            "revenue_center_id": revenue_center_id,
            "number_of_people_in_party": number_of_people_in_party,
            "user_id": user_id,
            "device_id": device_id,
            "business_expense": business_expense
        }

        if custom_ticket_name != None:
            ticket_body["custom_ticket_name"] = custom_ticket_name

        if table_id is not None:
            ticket_body['table_id'] = table_id

        ticket_response = self._swagger_locations_api.createTicket(location_id=self._location_id,
                                                                   api_key=self._api_key,
                                                                   ticket_type='take-out',
                                                                   body=ticket_body)
        if ticket_response.success == True:
            return SDTicket(parent=self, location=self, ticket_id=ticket_response.ticket_id, user_id=user_id, get_values=False)
        else:
            raise RuntimeError('Ticket Not Created: ' + ticket_response.error)

    def open_ticket_for_delivery(self, user_id):

        #Return a SDTicket
        pass

    @property
    def tickets(self):
        """


        :return:
        """
        return SDTicketCollection(parent=self)


#!/usr/bin/env python
"""
Copyright 2012 Wordnik, Inc.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""
class Tab:
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        self.swaggerTypes = {
            'payment_id': 'int',
            'name_on_card': 'str',
            'card_type': 'str',
            'expiration_year': 'str',
            'card_nickname': 'str',
            'card_id': 'int',
            'expiration_month': 'str',
            'pos_ticket_id': 'int',
            'table_id': 'int',
            'ticket_id': 'int',
            'table_name': 'str',
            'pre_auth_amount': 'float',
            'last_4_digits': 'str'

        }


        #SubtleData Payment ID
        self.payment_id = None # int
        #Name on Credit Card
        self.name_on_card = None # str
        #Credit Card Type
        self.card_type = None # str
        #Expiration Year
        self.expiration_year = None # str
        #Credit Card Nickname
        self.card_nickname = None # str
        #SubtleData Credit Card ID
        self.card_id = None # int
        #Expiration Month
        self.expiration_month = None # str
        #POS System Ticket Identifier
        self.pos_ticket_id = None # int
        #Table ID
        self.table_id = None # int
        #Ticket ID
        self.ticket_id = None # int
        #Table Name
        self.table_name = None # str
        #Pre Auth Amount
        self.pre_auth_amount = None # float
        #Last 4 Digits on Card
        self.last_4_digits = None # str
        



__author__ = 'gsibble'

from base_types import SDFirstClassObject
import exceptions as Exceptions

class SDTicket(SDFirstClassObject):
    def __init__(self, parent, location, ticket_id, user_id=0, get_values=True, swagger_ticket=None, *args, **kwargs):
        """

        :param parent:
        :param location:
        :param ticket_id:
        :param user_id:
        :param get_values:
        :param swagger_ticket:
        :param args:
        :param kwargs:
        """
        super(SDTicket, self).__init__(parent, False)

        self.ticket_id = ticket_id
        self.user_id = user_id
        self.location = location

        if swagger_ticket is None or get_values == True:
            self.refresh()
        else:
            self.refresh(swagger_ticket=swagger_ticket)

    def refresh(self, swagger_ticket=None):
        """

        :param swagger_ticket:
        """
        if swagger_ticket is None:
            self._swagger_ticket = self._swagger_locations_api.getTicket(self.location.location_id, self.ticket_id, api_key=self._api_key)
        else:
            self._swagger_ticket = swagger_ticket

        if self._swagger_ticket is not None:
            for attribute in self._swagger_ticket.swaggerTypes:
                self.__setattr__(attribute, getattr(self._swagger_ticket, attribute))


    def add_item_to_order(self, item_id, quantity, instructions=None, modifiers=None):

        """

        :param item_id:
        :param quantity:
        :param instructions:
        :param modifiers:
        :return: :raise:
        """
        if hasattr(self, 'user_id') and hasattr(self, 'ticket_id'):

            #If we don't have a user_id, use the default user of 0
            if self.user_id is None:
                user_id = 0

            #But if we do have a user, use them
            else:
                user_id = self.user_id

            if self.ticket_id is not None:
                post_body = {
                    'item_id': int(item_id),
                    'quantity': quantity
                    }

                if instructions is not None:
                    post_body['instructions'] = instructions

                if modifiers is not None:
                    post_body['modifiers'] = modifiers

                #print post_body

                returned_status = self._swagger_locations_api.addItemsToOrder(location_id=self.location.location_id,
                                                                              ticket_id=self.ticket_id,
                                                                              user_id=user_id,
                                                                              api_key=self._api_key,
                                                                              body=post_body)

                return returned_status
            else:

                raise Exceptions.NoTicketID
        else:
            raise Exceptions.NoUserSetOnTicket

    def submit_order(self):
        """


        :return: :raise:
        """
        if hasattr(self, 'user_id') and hasattr(self, 'ticket_id'):

            #If we don't have a connected user, use the default user 0
            if self.user_id is None:
                user_id = 0
            else:
                user_id = self.user_id

            if self.ticket_id is not None:
                returned_status = self._swagger_locations_api.submitOrder(location_id=self.location.location_id,
                                                                          ticket_id=self.ticket_id,
                                                                          user_id=user_id,
                                                                          api_key=self._api_key)

                return returned_status
            else:
                raise Exceptions.NoTicketID
        else:
            raise Exceptions.NoUserSetOnTicket

    def add_discount(self, discount_type_id, discount, user_id=0):
        """

        :param discount_type_id:
        :param discount:
        :param user_id:
        :return: :raise:
        """
        if discount > self.total:
            raise ValueError('You cannot discount a ticket more than its total amount')

        discountBody = {
            'discount_type': discount_type_id,
            'discount_amount': discount,
            'user_id': user_id
        }

        discountStatus = self._swagger_locations_api.discountTicket(location_id=self.location.location_id,
                                                                    ticket_id=self.ticket_id,
                                                                    api_key=self._api_key,
                                                                    body=discountBody)

        self.refresh()

        return discountStatus

    def pay_with_external_source(self, amount, tip_amount, user_id, device_id, tender_type_id, payment_source_name):

        payment_body = {
          "payment_source_name": payment_source_name,
          "tip_amount": tip_amount,
          "amount_before_tip": amount,
          "tender_type_id": tender_type_id,
          "user_id": user_id,
          "device_id": device_id
        }

        paymentStatus = self._swagger_locations_api.addExternalPaymentToTicket(location_id=self.location.location_id,
                                                                               ticket_id=self.ticket_id,
                                                                               body=payment_body,
                                                                               api_key=self._api_key)
        self.refresh()

        return paymentStatus

    def void(self):
        voidStatus = self._swagger_locations_api.voidTicket(location_id=self.location.location_id,
                                                            ticket_id=self.ticket_id,
                                                            api_key=self._api_key)

        return voidStatus

    def cancel(self):

        return self.void()


#!/usr/bin/env python
"""
Copyright 2012 Wordnik, Inc.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""
class OpenTicket:
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        self.swaggerTypes = {
            'employee_id': 'int',
            'user_id': 'int',
            'number_of_guests': 'int',
            'items': 'list[Item]',
            'tax': 'float',
            'discount': 'float',
            'pos_ticket_id': 'int',
            'remaining_balance': 'float',
            'table_id': 'int',
            'ticket_id': 'int',
            'date_opened': 'str',
            'table_name': 'str',
            'total': 'float',
            'subtotal': 'float',
            'service_charge': 'float'

        }


        #Employee ID
        self.employee_id = None # int
        #User ID
        self.user_id = None # int
        #Number of guests on ticket
        self.number_of_guests = None # int
        self.items = None # list[Item]
        #Tax amount
        self.tax = None # float
        #Discount amount
        self.discount = None # float
        #POS System Ticket Identifier
        self.pos_ticket_id = None # int
        #Ticket remaining balance
        self.remaining_balance = None # float
        #Table ID
        self.table_id = None # int
        #Ticket ID
        self.ticket_id = None # int
        #Date/Time Ticket Opened
        self.date_opened = None # str
        #Table Name
        self.table_name = None # str
        #Total amount
        self.total = None # float
        #Subtotal amount
        self.subtotal = None # float
        #Service charge
        self.service_charge = None # float
        



#!/usr/bin/env python
"""
Copyright 2012 Wordnik, Inc.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""
class MenuItem:
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        self.swaggerTypes = {
            'sku': 'str',
            'food_flag': 'bool',
            'alcohol_flag': 'bool',
            'display_name': 'str',
            'name': 'str',
            'merchandise_flag': 'bool',
            'available_for_order': 'bool',
            'price': 'float',
            'description': 'str',
            'UPC': 'str',
            'ModifierTypes': 'list[Modifiertype]',
            'item_images': 'list[ItemImage]',
            'cost': 'float',
            'revenue_center_id': 'int',
            'item_id': 'int',
            'local_pos_id': 'int',
            'out_of_stock_flag': 'bool'

        }


        #Item SKU
        self.sku = None # str
        #Food Flag
        self.food_flag = None # bool
        #Alcohol Flag
        self.alcohol_flag = None # bool
        #Item Display Name
        self.display_name = None # str
        #Item Name
        self.name = None # str
        #Merchandise Flag
        self.merchandise_flag = None # bool
        #Available For Order Flag
        self.available_for_order = None # bool
        #Item Price
        self.price = None # float
        #Item Description
        self.description = None # str
        #Item UPC
        self.UPC = None # str
        self.ModifierTypes = None # list[Modifiertype]
        self.item_images = None # list[ItemImage]
        #Item Cost Basis
        self.cost = None # float
        #Revenue Center ID
        self.revenue_center_id = None # int
        #Item ID
        self.item_id = None # int
        #Item POS ID
        self.local_pos_id = None # int
        #Out of Stock
        self.out_of_stock_flag = None # bool
        



__author__ = 'gsibble'

from base_types import SDFirstClassCollection
from sd_ticket import SDTicket

class SDTicketCollection(SDFirstClassCollection):

    def __init__(self, parent):
        """

        :param parent:
        """
        super(SDTicketCollection, self).__init__(parent)
        self.parent = parent
        self.location = parent
        self._all_tickets = None

    def get_with_sd_id(self, ticket_id):

        """

        :param ticket_id:
        :return:
        """
        return SDTicket(parent=self, location=self.location, ticket_id=ticket_id)

    def get_with_pos_id(self, pos_ticket_id):
        """

        :param pos_ticket_id:
        :return:
        """
        swagger_ticket = self._swagger_locations_api.getTicketWithPOS_ID(location_id=self.location.location_id,
                                                                         pos_ticket_id=pos_ticket_id, api_key=self._api_key)

        return SDTicket(parent=self, location=self.location, ticket_id=swagger_ticket.ticket_id)

    def refresh(self):
        """


        """
        self._swagger_tickets = self._swagger_locations_api.getTickets(location_id=self.location.location_id,
                                                                       api_key=self._api_key)

        self._all_tickets = [SDTicket(parent=self, location=self.location, ticket_id=ticket.ticket_id, user_id=ticket.user_id, swagger_ticket=ticket, get_values=False) for ticket in self._swagger_tickets]

    @property
    def all(self):
        """


        :return:
        """
        if self._all_tickets is None:
            self.refresh()

        return self._all_tickets


__author__ = 'gsibble'

#Custom Exceptions

class NoUserSetOnTicket(Exception):
    pass

class NoTicketID(Exception):
    pass

class UserNotCreated(Exception):
    pass

class UserLoginError(Exception):
    pass


__author__ = 'gsibble'

from base_types import SDFirstClassCollection

from sd_table import SDTable

class SDTableCollection(SDFirstClassCollection):

    def __init__(self, parent):
        """

        :param parent:
        """
        super(SDTableCollection, self).__init__(parent)
        self.parent = parent
        self.location = parent
        self._all_tables = None

    def get_with_pos_id(self, pos_table_id):
        """

        :param pos_table_id:
        :return:
        """
        for table in self.all:
            if table.pos_table_id == pos_table_id:
                return table
        else:
            return None

    def get_with_sd_id(self, sd_table_id):
        """

        :param sd_table_id:
        :return:
        """
        for table in self.all:
            if table.subtledata_id == sd_table_id:
                return table
        else:
            return None

    def refresh(self):
        """


        """
        self._swagger_tables = self._swagger_locations_api.getTableList(location_id=self.location.location_id,
                                                                        api_key=self._api_key)

        #Set the tables to be our type
        self._all_tables = [SDTable(parent=self, location=self.location, swagger_table=table) for table in self._swagger_tables]


    @property
    def all(self):

        """


        :return:
        """
        if self._all_tables is None:
            self.refresh()

        return self._all_tables


__author__ = 'gsibble'

from base_types import SDFirstClassCollection

from sd_location import SDLocation

class SDLocationCollection(SDFirstClassCollection):

    def __init__(self, parent):
        """

        :param parent:
        """
        super(SDLocationCollection, self).__init__(parent)

    @property
    def all(self):


        #Get all locations via swagger
        """


        :return:
        """
        self._swagger_locations = self._swagger_locations_api.getAllLocations(self._api_key, use_cache=self._use_cache)

        return [SDLocation(parent=self, location_id=location.location_id, fetch=False, initial_data=location) for location in self._swagger_locations]


    def get(self, location_id, use_cache=True, include_menu=False):
        """

        :param location_id:
        :param use_cache:
        :param include_menu:
        :return:
        """
        if not self._use_cache:
            use_cache = False

        return SDLocation(self, location_id, include_menu, use_cache)

    def filter(self, name=None, postal_code=None):

        """

        :param name:
        :param postal_code:
        :return:
        """
        return []

    def near(self, latitude, longitude, radius):

        """

        :param latitude:
        :param longitude:
        :param radius:
        :return:
        """
        return []

    def create(self):
        pass



#!/usr/bin/env python
"""
Copyright 2012 Wordnik, Inc.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""
class Ticket:
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        self.swaggerTypes = {
            'date_closed': 'str',
            'tax': 'float',
            'date_opened': 'str',
            'total': 'float',
            'location_id': 'int',
            'employee_id': 'int',
            'ticket_open': 'bool',
            'pre_auth_payments': 'list[PreAuthPayment]',
            'remaining_balance': 'float',
            'ticket_id': 'int',
            'table_name': 'str',
            'revenue_center_id': 'int',
            'user_id': 'int',
            'pre_auth_cards': 'list[PreAuthCard]',
            'discount': 'float',
            'external_payments': 'list[ExternalPayment]',
            'cover_count': 'int',
            'subtotal': 'float',
            'service_charge': 'float',
            'date_modified': 'str',
            'items': 'list[Item]',
            'pos_ticket_id': 'int',
            'table_id': 'int',
            'payments': 'list[Payment]',
            'connected_users': 'list[ConnectedUser]'

        }


        #Date Closed (UTC)
        self.date_closed = None # str
        #Tax amount
        self.tax = None # float
        #Date Opened (UTC)
        self.date_opened = None # str
        #Total amount
        self.total = None # float
        #Location ID
        self.location_id = None # int
        #Employee ID
        self.employee_id = None # int
        #Ticket open/closed status
        self.ticket_open = None # bool
        self.pre_auth_payments = None # list[PreAuthPayment]
        #Ticket remaining balance
        self.remaining_balance = None # float
        #Ticket ID
        self.ticket_id = None # int
        #Table Name
        self.table_name = None # str
        #Revenue Center ID
        self.revenue_center_id = None # int
        #User ID
        self.user_id = None # int
        self.pre_auth_cards = None # list[PreAuthCard]
        #Discount amount
        self.discount = None # float
        self.external_payments = None # list[ExternalPayment]
        #Cover Count
        self.cover_count = None # int
        #Subtotal amount
        self.subtotal = None # float
        #Service charge
        self.service_charge = None # float
        #Date Modified (UTC)
        self.date_modified = None # str
        self.items = None # list[Item]
        #POS System Ticket Identifier
        self.pos_ticket_id = None # int
        #Table ID
        self.table_id = None # int
        self.payments = None # list[Payment]
        self.connected_users = None # list[ConnectedUser]
        



__author__ = 'gsibble'

from base_types import SDFirstClassCollection

from sd_user import SDUser

import exceptions as Exceptions

from urllib2 import HTTPError

class SDUserCollection(SDFirstClassCollection):

    def __init__(self, parent):
        """
        Set up our user list
        :param parent:
        """
        super(SDUserCollection, self).__init__(parent)

    @property
    def all(self):
        """
        Get all users available with the current API Key

        :return: List of SDUser objects
        """
        return []


    def get(self, user_id, use_cache=True):
        """
        Get a user based upon user_id
        :param user_id:
        :param use_cache:
        :return: SDUser object
        """
        if not self._use_cache:
            use_cache = False

        try:
            user = SDUser(self, user_id=user_id, use_cache=use_cache)
        except HTTPError:
            user = None
        return user

    def getWithUsername(self, user_name, use_cache=True):
        if not self._use_cache:
            use_cache = False

        try:
            user = SDUser(self, user_name=user_name, use_cache=use_cache)
        except HTTPError:
            user = None

        return user

    def filter(self, first_name=None):
        """
        Get a user based upon other criteria
        :param first_name:
        :return:
        """
        return []

    def login(self, device_uuid, password, user_id=None, user_name=None, latitude=None, longitude=None):

        login_body = {
          "device_uuid": device_uuid,
          "password": password
        }

        if user_id:
            login_body['user_id'] = user_id
        else:
            login_body['user_name'] = user_name

        if latitude and longitude:
            login_body['latitude'] = latitude
            login_body['longitude'] = longitude

        #Login the user
        login_result = self._swagger_users_api.authUser(api_key=self._api_key, body=login_body)

        if login_result.success == True:
            user = self.get(login_result.user_id, use_cache=False)
            user.__setattr__('device_id', login_result.device_id)
        else:
            raise Exceptions.UserLoginError

        return user

    def create(self, user_name, password, first_name,
               last_name, device_uuid,
               email_address, cell_phone,
               middle_name=None,
               dob=None,
               latitude=None, longitude=None):
        """
        Create a new user with the passed details
        :param user_name: SubtleData user name
        :param password: SubtleData user password
        :param device_uuid: The user's current device
        :param email_address: The user's email address
        :param cell_phone: The user's cell phone
        :return: SDUser object :raise: UserNotCreated if error
        """

        #Set up our new_user POST request
        new_user_body = {'user_name': user_name,
                         'password': password,
                         'first_name': first_name,
                         'last_name': last_name,
                         'device_uuid': device_uuid,
                         'email_address': email_address,
                         'cell_phone': cell_phone}

        #If we are passed a DOB, add it to the call
        if dob:
            new_user_body['dob'] = dob

        #If we are passed a middle name, add it to the call
        if middle_name:
            new_user_body['middle_name'] = middle_name

        #If we are passed a location, add it to the call
        if latitude and longitude:
            new_user_body['latitude'] = float(latitude)
            new_user_body['longitude'] = float(longitude)

        #Make the request to create the new user
        new_user_data = self._swagger_users_api.createUser(api_key=self._api_key, body=new_user_body)

        #Try to fetch the new user's details
        try:

            user_id = new_user_data.user_id
            device_id = new_user_data.device_id
            print user_id
            print device_id

        except KeyError:
            raise Exceptions.UserNotCreated

        #Create our User object by fetching all details
        new_user = self.get(user_id)

        #Set the device ID of the new user
        new_user.__setattr__('device_id', device_id)

        #Return our user object
        return new_user